@@ -103,6 +103,10 @@ def parse_args(args):
         help="print Clade version",
         action="store_true",
     )
+    parser.add_argument(
+        "--cif",
+        help="name or path of the CIF to use",
+    )
     parser.add_argument(
         dest="command",
         nargs=argparse.REMAINDER,
@@ -140,6 +144,8 @@ def prepare_conf(args):
     conf["preset"] = args.preset
     conf["command"] = args.command
 
+    conf["Info.cif"] = args.cif if args.cif else conf.get("Info.cif", "cif")
+
     return conf
 
 
